@@ -1,17 +1,13 @@
-use super::{impl_spanning, Span, Spanned, Spanning};
-
 #[derive(Debug, Copy, Clone)]
-pub struct Instruction {
-    pub instruction_kind: InstructionKind,
-    pub keep: bool,
-    pub r#return: bool,
-    pub short: bool,
+pub(crate) struct Instruction {
+    pub(crate) instruction_kind: InstructionKind,
+    pub(crate) keep: bool,
+    pub(crate) r#return: bool,
+    pub(crate) short: bool,
 }
 
-impl_spanning!(Instruction);
-
 #[derive(Debug, Copy, Clone)]
-pub enum InstructionKind {
+pub(crate) enum InstructionKind {
     Break,
     Literal,
     NoOperation,
