@@ -7,7 +7,7 @@ use std::fmt;
 mod hex_number;
 
 #[derive(Clone)]
-enum Evaluated {
+pub(crate) enum Word {
     Fine {
         token: Spanned<Token>,
         warnings: Vec<Warning>,
@@ -18,20 +18,6 @@ enum Evaluated {
     },
 }
 
-impl fmt::Debug for Evaluated {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        match self {
-            Self::Fine { token, .. } => write!(f, "Fine {{ token: {:?} }}", token.node),
-            Self::Faulty { .. } => write!(f, "Faulty"),
-        }
-    }
-}
-
-#[derive(Debug, Clone)]
-pub(crate) struct Word {
-    evaluated: Evaluated,
-}
-
 impl Word {
     pub(crate) fn new(symbols: &[Spanned<char>]) -> Self {
         debug_assert!({
@@ -41,23 +27,12 @@ impl Word {
             WHITESPACES.iter().all(|ch| !chars.contains(ch))
         });
 
-        let evaluated = match tokenize(symbols) {
-            Ok((token, warnings)) => Evaluated::Fine { token, warnings },
-            Err(error) => Evaluated::Faulty {
+        match tokenize(symbols) {
+            Ok((token, warnings)) => Self::Fine { token, warnings },
+            Err(error) => Self::Faulty {
                 errors: vec![error],
                 warnings: Vec::new(),
             },
-        };
-
-        Self { evaluated }
-    }
-
-    pub(crate) fn get_token(
-        &self,
-    ) -> Result<(Spanned<Token>, Vec<Warning>), (Vec<Error>, Vec<Warning>)> {
-        match &self.evaluated {
-            Evaluated::Fine { token, warnings } => Ok((token.clone(), warnings.clone())),
-            Evaluated::Faulty { errors, warnings } => Err((errors.clone(), warnings.clone())),
         }
     }
 }
@@ -89,6 +64,11 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<Warning>), Er
                     number: to_string(&word[1..]),
                     span: span.into(),
                 },
+                hex_number::Error2::TooLong { length } => Error::HexNumberTooLong {
+                    length,
+                    number: to_string(&word[1..]),
+                    span: to_span(&word[1..]).unwrap().into(),
+                },
             })
             .map(|value| Token::PadAbsolute(value))
             .map(|token| (token.spanning(to_span(word).unwrap()), Vec::new())),
@@ -100,6 +80,11 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<Warning>), Er
                     number: to_string(&word[1..]),
                     span: span.into(),
                 },
+                hex_number::Error2::TooLong { length } => Error::HexNumberTooLong {
+                    length,
+                    number: to_string(&word[1..]),
+                    span: to_span(&word[1..]).unwrap().into(),
+                },
             })
             .map(|value| Token::PadRelative(value))
             .map(|token| (token.spanning(to_span(word).unwrap()), Vec::new())),
@@ -230,9 +215,9 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<Warning>), Er
                 }
             }
         }
-        Spanned { node: '"', span } => {
+        Spanned { node: '"', .. } => {
             return Ok((
-                Token::RawWord(to_string(&word[1..])).spanning(span),
+                Token::RawWord(to_string(&word[1..])).spanning(to_span(word).unwrap()),
                 Vec::new(),
             ));
         }
@@ -256,7 +241,7 @@ fn tokenize(word: &[Spanned<char>]) -> Result<(Spanned<Token>, Vec<Warning>), Er
             return Ok((
                 to_spanned_string(word)
                     .unwrap()
-                    .map(|s| (Token::MacroExpand(s))),
+                    .map(|s| (Token::MacroInvoke(s))),
                 Vec::new(),
             ));
         }
@@ -460,3 +445,26 @@ fn parse_instruction(symbols: &[Spanned<char>]) -> Option<(Instruction, Vec<Warn
         warnings,
     ));
 }
+
+impl fmt::Debug for Word {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self {
+            Word::Fine { token, warnings } => {
+                let mut debug_struct = f.debug_struct("Fine");
+                debug_struct.field("token", token);
+                if !warnings.is_empty() {
+                    debug_struct.field("warnings", warnings);
+                }
+                debug_struct.finish()
+            }
+            Word::Faulty { errors, warnings } => {
+                let mut debug_struct = f.debug_struct("Faulty");
+                debug_struct.field("errors", errors);
+                if !warnings.is_empty() {
+                    debug_struct.field("warnings", warnings);
+                }
+                debug_struct.finish()
+            }
+        }
+    }
+}
